@@ -12,9 +12,6 @@
 #' @details The number of raters implied by the entries in the rater column
 #'   must match the number of raters in the fitted model.
 #'
-#'   Due to technical issues drawing from the posterior predictive distribution
-#'   of the hierarchical Dawid-Skene model is currently not supported.
-#'
 #' @examples
 #'
 #' \donttest{
@@ -40,10 +37,6 @@ posterior_predict.rater_fit <- function(object, new_data, seed = NULL, ...) {
   }
 
   fit <- object
-  if (inherits(get_model(fit), "hier_dawid_skene")) {
-    stop("The posterior_predict is not currently implmented for the ",
-         "\n Hierarchical Dawid-Skene model.", call. = FALSE)
-  }
 
   new_data <- as.data.frame(new_data)
   col_names <- colnames(new_data)
