@@ -46,21 +46,17 @@ test_that("Plotting works for grouped data Dawid-Skene (MCMC + optimisation) (sm
 
 test_that("plot_prevalence output has correct type", {
   ds_plot <- plot_pi(ds_fit)
-  expect_equal(get_geoms(ds_plot), c("GeomPoint", "GeomErrorbar"))
 })
 
 test_that("plot_raters output has correct type", {
   ds_plot <- plot_theta(ds_fit)
   expect_equal(get_facet_dim(ds_plot), 5)
-  expect_equal(get_geoms(ds_plot), c("GeomTile", "GeomText"))
 })
 
 test_that("plot_latent_class output has correct type", {
   ds_plot <- plot_class_probabilities(ds_fit)
-  expect_equal(get_geoms(ds_plot), c("GeomTile", "GeomText"))
 })
 
 test_that("plot_theta_points output has correct type", {
   ds_plot <- plot_theta_points(ds_fit)
-  expect_equal(get_geoms(ds_plot), c("GeomPoint", "GeomErrorbar"))
 })
